@@ -5,7 +5,7 @@
 from __future__ import absolute_import
 
 __all__ = ["LL"]
-__version__ = '0.0.10'
+__version__ = '0.0.11'
 __author__ = 'Fluxim AG'
 __copyright__ = "Copyright 2020, Fluxim AG, Winterthur, Switzerland"
-__email__ = "olivier.scholder@fluxim.com"
+__email__ = "stefano.sem@fluxim.com"
